#ifndef _PPC_TYPES_H
#define _PPC_TYPES_H

#ifndef __ASSEMBLY__

typedef __signed__ char __s8;
typedef unsigned char __u8;

typedef __signed__ short __s16;
typedef unsigned short __u16;

typedef __signed__ int __s32;
typedef unsigned int __u32;

#if (defined(__GNUC__) && !defined(__STRICT_ANSI__)) || (__STDC_VERSION__ >= 199901L)
typedef __signed__ long long __s64;
typedef unsigned long long __u64;
#endif

#if (defined(__STRICT_ANSI__) && !defined(inline))
#define inline __inline__
#endif

typedef struct {
	__u32 u[4];
} __vector128;

/*
 * XXX allowed outside of __KERNEL__ for now, until glibc gets
 * a proper set of asm headers of its own.  -- paulus
 */
typedef unsigned short umode_t;

#endif /* __ASSEMBLY__ */

#endif
